.. equinox documentation master file

equinox Documentation
==============================

.. image:: equinox-logo.png
  :width: 100
  :alt: equinox Logo
  :align: left

**Equinox** is an open source platform for collecting and reporting risk and sustainability information about project finance. Equinox implements and integrates a number of regulatory or industry standards that cover the space of GHG emissions attribution and reporting and ESG risk analysis.

The full list of implemented standards is in :ref:`References`


.. note:: The equinox project is still in its early phases and is not yet suitable for deployment.


Overview
-----------

* Author: `Open Risk <http://www.openriskmanagement.com>`_
* License: MIT
* Development Website: `Github <https://github.com/open-risk/equinox>`_
* Online Code Documentation: `Read The Docs <https://equinox-server.readthedocs.io/en/latest/>`_
* Project Discussion: `Open Risk Commons <https://www.openriskcommons.org/c/sustainable-finance>`_
* Docker Image: Coming
* Training: Coming: `Open Risk Academy <https://www.openriskacademy.com/>`_


.. toctree::
   :maxdepth: 2
   :caption: Getting Started:

   description
   setup
   requirements
   loading_sample_data


.. toctree::
   :maxdepth: 2
   :caption: Technical Documentation:

   modules
   applications
   api
   api_docs
   changelog
   contributing

.. toctree::
   :maxdepth: 2
   :caption: User Documentation:

   getting_started
   pages
   reference_data
   GHG_Project
   PCAF
   CIRIS
   EBA_Scorecard
   References


Further Supporting Documentation
---------------------------------

* `Open Risk Manual (Sustainable Finance) <https://www.openriskmanual.org/wiki/Category:Sustainable_Finance>`_
* `Open Risk Manual (Project Finance) <https://www.openriskmanual.org/wiki/Category:Project_Finance>`_
* `Open Risk Manual (GHG Protocol) <https://www.openriskmanual.org/wiki/Category:GHG_Protocol>`_


Indexes and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
